"""
Vars here can be passed to __init__ method in lowercase version
to override the default, i.e.: whm(domain, username, api_token, whm_port=2086) would override the port
"""

API_VERSION = 1
WHM_PORT = 2087
WHM_PROTOCOL = 'https://'
API_TYPE = 'json-api'
VERIFY_SSL = False
